@@ -145,9 +145,7 @@ class Cashflow:
         
 
     def regress_growth_function(self):
-        to_array = []
-        for date in self.sample:
-            to_array.append(self.sample[date])
+        to_array = [ self.sample[date] for date in self.sample ]
 
         self.beta = statistics.regression_beta(x=self.time_series, y=to_array)
         self.alpha = statistics.regression_alpha(x=self.time_series, y=to_array)
@@ -162,6 +160,17 @@ class Cashflow:
         else:
             logger.debug(f'Linear regression model : y = {self.beta} * x + {self.alpha}')
 
+    def generate_model_series(self):
+        return [self.alpha + self.beta*time for time in self.time_series]
+
+    def generate_model_comparison(self):
+        model_prices= self.generate_model_series()
+
+        return[ { 'date': date, 
+                  'model_price': self.sample[date], 
+                  'actual_price': model_prices[index] } 
+                for index, date in enumerate(self.sample.keys()) ]
+        
     def get_growth_function(self, x):
         if self.growth_function is None:
             if self.constant is not None:
